@@ -1,12 +1,13 @@
 # flake8: noqa
 
-__version__ = '0.1.2'
+__version__ = "0.1.3"
 
 from .client import initialize
 
 from .model import BaseModel
 
 from .property import (
+    PropertySpecialValue,
     BaseProperty,
     StringProperty,
     IntegerProperty,
@@ -15,11 +16,12 @@ from .property import (
     TimestampProperty,
     JsonProperty,
     ComputedProperty,
-    ConstantProperty
+    ConstantProperty,
 )
 
 from .exceptions import (
     FsglueException,
     FsglueProgrammingError,
-    FsglueValidationError
+    FsglueValidationError,
+    FsglueDocumentNotFound,
 )
